@@ -48,6 +48,8 @@ from bitmovin_api_sdk.models.akamai_msl_version import AkamaiMslVersion
 from bitmovin_api_sdk.models.akamai_net_storage_input import AkamaiNetStorageInput
 from bitmovin_api_sdk.models.akamai_net_storage_output import AkamaiNetStorageOutput
 from bitmovin_api_sdk.models.analytics_abstract_filter import AnalyticsAbstractFilter
+from bitmovin_api_sdk.models.analytics_ads_impression_sample import AnalyticsAdsImpressionSample
+from bitmovin_api_sdk.models.analytics_ads_impressions_response import AnalyticsAdsImpressionsResponse
 from bitmovin_api_sdk.models.analytics_attribute import AnalyticsAttribute
 from bitmovin_api_sdk.models.analytics_avg_concurrent_viewers_response import AnalyticsAvgConcurrentViewersResponse
 from bitmovin_api_sdk.models.analytics_avg_dropped_frames_response import AnalyticsAvgDroppedFramesResponse
@@ -213,6 +215,7 @@ from bitmovin_api_sdk.models.dash_chunked_text_representation import DashChunked
 from bitmovin_api_sdk.models.dash_cmaf_representation import DashCmafRepresentation
 from bitmovin_api_sdk.models.dash_fmp4_drm_representation import DashFmp4DrmRepresentation
 from bitmovin_api_sdk.models.dash_fmp4_representation import DashFmp4Representation
+from bitmovin_api_sdk.models.dash_imsc_representation import DashImscRepresentation
 from bitmovin_api_sdk.models.dash_manifest import DashManifest
 from bitmovin_api_sdk.models.dash_manifest_default import DashManifestDefault
 from bitmovin_api_sdk.models.dash_manifest_default_version import DashManifestDefaultVersion
@@ -382,6 +385,9 @@ from bitmovin_api_sdk.models.id3_tag_type import Id3TagType
 from bitmovin_api_sdk.models.ignored_by import IgnoredBy
 from bitmovin_api_sdk.models.ignoring import Ignoring
 from bitmovin_api_sdk.models.image_adaptation_set import ImageAdaptationSet
+from bitmovin_api_sdk.models.imsc_configuration import ImscConfiguration
+from bitmovin_api_sdk.models.imsc_styling import ImscStyling
+from bitmovin_api_sdk.models.imsc_styling_mode import ImscStylingMode
 from bitmovin_api_sdk.models.infrastructure_settings import InfrastructureSettings
 from bitmovin_api_sdk.models.ingest_input_stream import IngestInputStream
 from bitmovin_api_sdk.models.input import Input
